package nodatafound.mjpmsuc;

import org.junit.jupiter.api.Test;

public class ExportedPublicTest {

  @Test
  public void test_package_protected_class() {
    /*
     * mockito is in class path: it should be able to access package protected class
     */
    final nodatafound.mjpmsuc.ExportedProtected b = org.mockito.Mockito.mock(nodatafound.mjpmsuc.ExportedProtected.class);
    System.out.println(b);
  }

  @Test
  public void test_public_class_not_exported() {
    /*
     * mockito is in class path: it should be able to access public class (if I'm not wrong) even if
     * not exported.
     */
    final nodatafound.mjpmsuc.internal.NotExportedNotOpenedPublic c = org.mockito.Mockito
        .mock(nodatafound.mjpmsuc.internal.NotExportedNotOpenedPublic.class);
    System.out.println(c);
  }

  @Test
  public void test_public_class_not_exported_but_opened_to_mockito() {
    /*
     * mockito is in class path, but we use a opens specific to mockito (it has a
     * "Automatic-Module-Name"): it should be able to access public class (if
     * I'm not wrong).
     */
    final nodatafound.mjpmsuc.withopens.NotExportedOpenToMockitoPublic d = org.mockito.Mockito
        .mock(nodatafound.mjpmsuc.withopens.NotExportedOpenToMockitoPublic.class);
    System.out.println(d);
  }

  @Test
  public void test_public_class_not_exported_but_widely_opened() {
    /*
     * mockito is in class path, but we use a wide opens: mockito should be able to access public
     * class.
     */
    final nodatafound.mjpmsuc.withwideopens.NotExportedWidelyOpenedPublic e = org.mockito.Mockito
        .mock(nodatafound.mjpmsuc.withwideopens.NotExportedWidelyOpenedPublic.class);
    System.out.println(e);
  }

  @Test
  public void test_with_a_java_10_module_added_as_dependency() {
    /*
     * TheMocker is in another module, but as I understood, it should be visible because a test
     * dependency - at least with m2e/maven - is always put in the classpath, regardless of it being
     * a module.
     *
     * note: the dependency [unittest-shared] is a test dependency [without test code] in Eclipse.
     *
     * And if not in class path, then that means I'd need a module-info.java for tests, which is
     * fine by itself,
     * but clearly not clear.
     */

    final nodatafound.mjpmsuc.ExportedProtected b = nodatafound.utshared.TheMocker.mocker(() -> new nodatafound.mjpmsuc.ExportedProtected());
    System.out.println(b);
  }
}
